aboutsummaryrefslogtreecommitdiff
path: root/src/core/lombok
diff options
context:
space:
mode:
authorRoel Spilker <r.spilker@gmail.com>2010-11-10 20:38:42 +0100
committerRoel Spilker <r.spilker@gmail.com>2010-11-10 20:38:42 +0100
commitc8774389e7cb73e494267af3a87f70c7497b220a (patch)
tree12547a1ef298f0c2a5eebd6c7b6cdd359c5183e4 /src/core/lombok
parent3d4b27d6d288ecb418a2a1a09ed43cae90ec548e (diff)
downloadlombok-c8774389e7cb73e494267af3a87f70c7497b220a.tar.gz
lombok-c8774389e7cb73e494267af3a87f70c7497b220a.tar.bz2
lombok-c8774389e7cb73e494267af3a87f70c7497b220a.zip
Made AnyAnnotation deprecated
Diffstat (limited to 'src/core/lombok')
-rw-r--r--src/core/lombok/Getter.java6
-rw-r--r--src/core/lombok/Setter.java8
2 files changed, 9 insertions, 5 deletions
diff --git a/src/core/lombok/Getter.java b/src/core/lombok/Getter.java
index 2c686595..7e545ae0 100644
--- a/src/core/lombok/Getter.java
+++ b/src/core/lombok/Getter.java
@@ -58,16 +58,18 @@ public @interface Getter {
* If you want your setter to be non-public, you can specify an alternate access level here.
*/
lombok.AccessLevel value() default lombok.AccessLevel.PUBLIC;
-
+
/**
* If you want your getter method to have additional annotations, you can specify them here.<br/>
- * If the {code @Getter} is put on a type, {code onMethod} may not be specified.
+ * If the {@code @Getter} is put on a type, {@code onMethod} may not be specified.
*/
AnyAnnotation[] onMethod() default {};
/**
* Placeholder annotation to enable the placement of annotations on the getter method.
+ * @deprecated Don't use this annotation, since we might remove it.
*/
+ @Deprecated
@Retention(RetentionPolicy.SOURCE)
@interface AnyAnnotation {}
}
diff --git a/src/core/lombok/Setter.java b/src/core/lombok/Setter.java
index cd549fed..8c78bbb3 100644
--- a/src/core/lombok/Setter.java
+++ b/src/core/lombok/Setter.java
@@ -58,19 +58,21 @@ public @interface Setter {
/**
* If you want your setter method to have additional annotations, you can specify them here.
- * If the {code @Setter} is put on a type, {code onMethod} may not be specified.
+ * If the {@code @Setter} is put on a type, {@code onMethod} may not be specified.
*/
AnyAnnotation[] onMethod() default {};
/**
* If you want the parameter of your setter to have additional annotations, you can specify them here.
- * If the {code @Setter} is put on a type, {code onParam} may not be specified.
+ * If the {@code @Setter} is put on a type, {@code onParam} may not be specified.
*/
AnyAnnotation[] onParam() default {};
/**
* Placeholder annotation to enable the placement of annotations on the setter method or its parameter.
*/
+ @Deprecated
@Retention(RetentionPolicy.SOURCE)
@interface AnyAnnotation {}
} \ No newline at end of file
@@ -58,19 +58,21 @@ public @interface Setter {
AnyAnnotation[] onParam() default {};
/**
- * Placeholder annotation to enable the placement of annotations on the setter method or its parameter.
+ * Placeholder annotation to enable the placement of annotations on the setter method or its parameter.
+ * @deprecated Don't use this annotation, since we might remove it.
*/